@@ -1,5 +1,7 @@
 _base_ = ['./roi_trans_kfiou_ln_r50_fpn_1x_dota_le90.py']
 
+pretrained = 'https://github.com/SwinTransformer/storage/releases/download/v1.0.0/swin_tiny_patch4_window7_224.pth'  # noqa
+
 model = dict(
     backbone=dict(
         _delete_=True,
@@ -18,16 +20,12 @@ model = dict(
         out_indices=(0, 1, 2, 3),
         with_cp=False,
         convert_weights=True,
-        init_cfg=dict(
-            type='Pretrained',
-            checkpoint='torch/hub/checkpoints/'
-            'swin_tiny_patch4_window7_224.pth')),
+        init_cfg=dict(type='Pretrained', checkpoint=pretrained)),
     neck=dict(
         _delete_=True,
         type='FPN',
         in_channels=[96, 192, 384, 768],
         out_channels=256,
-        start_level=1,
         add_extra_convs='on_input',
         num_outs=5))
 
