@@ -1,6 +1,6 @@
-_base_ = ['./redet_re50_fpn_1x_dota_le90.py']
+_base_ = ['./redet_re50_refpn_1x_dota_le90.py']
 
-data_root = '/cluster/home/it_stu198/main/datasets/split_ms_dota1_0/'
+data_root = 'datasets/split_ms_dota1_0/'
 angle_version = 'le90'
 img_norm_cfg = dict(
     mean=[123.675, 116.28, 103.53], std=[58.395, 57.12, 57.375], to_rgb=True)
