@@ -1,10 +1,12 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+from .csl_rotated_retina_head import CSLRRetinaHead
 from .kfiou_odm_refine_head import KFIoUODMRefineHead
 from .kfiou_rotate_retina_head import KFIoURRetinaHead
 from .kfiou_rotate_retina_refine_head import KFIoURRetinaRefineHead
 from .odm_refine_head import ODMRefineHead
 from .oriented_rpn_head import OrientedRPNHead
 from .rotated_anchor_head import RotatedAnchorHead
+from .rotated_atss_head import RotatedATSSHead
 from .rotated_reppoints_head import RotatedRepPointsHead
 from .rotated_retina_head import RotatedRetinaHead
 from .rotated_retina_refine_head import RotatedRetinaRefineHead
@@ -15,5 +17,6 @@ __all__ = [
     'RotatedAnchorHead', 'RotatedRetinaHead', 'RotatedRPNHead',
     'OrientedRPNHead', 'RotatedRetinaRefineHead', 'ODMRefineHead',
     'KFIoURRetinaHead', 'KFIoURRetinaRefineHead', 'KFIoUODMRefineHead',
-    'RotatedRepPointsHead', 'SAMRepPointsHead'
+    'RotatedRepPointsHead', 'SAMRepPointsHead', 'CSLRRetinaHead',
+    'RotatedATSSHead'
 ]
